.. _sequence_to_stills:

laue_dials.sequence_to_stills
=============================

.. Introduction
.. ------------

.. .. python_string:: laue_dials.command_line.sequence_to_stills.help_message

Basic parameters
----------------

.. phil:: laue_dials.command_line.sequence_to_stills.phil_scope
   :expert-level: 0
   :attributes-level: 0


Full parameter definitions
--------------------------

.. phil:: laue_dials.command_line.sequence_to_stills.phil_scope
   :expert-level: 2
   :attributes-level: 2
